summaryrefslogtreecommitdiffstats
path: root/src/base/io
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/io')
-rw-r--r--src/base/io/io.c2
-rw-r--r--src/base/io/ioReadDsd.c10
-rw-r--r--src/base/io/ioWriteBench.c4
-rw-r--r--src/base/io/ioWriteEqn.c2
-rw-r--r--src/base/io/ioWriteList.c2
-rw-r--r--src/base/io/ioWriteSmv.c2
6 files changed, 11 insertions, 11 deletions
diff --git a/src/base/io/io.c b/src/base/io/io.c
index bf01c7b5..41b08e68 100644
--- a/src/base/io/io.c
+++ b/src/base/io/io.c
@@ -706,7 +706,7 @@ usage:
fprintf( pAbc->Err, "\t (in this case CA=11001010 is truth table of MUX(Data0,Data1,Ctrl))\n" );
fprintf( pAbc->Err, "\t The lower chars (a,b,c,etc) are reserved for elementary variables.\n" );
fprintf( pAbc->Err, "\t The upper chars (A,B,C,etc) are reserved for hexadecimal digits.\n" );
- fprintf( pAbc->Err, "\t No spaces are allowed in formulas. In parantheses, LSB goes first.\n" );
+ fprintf( pAbc->Err, "\t No spaces are allowed in formulas. In parentheses, LSB goes first.\n" );
return 1;
}
diff --git a/src/base/io/ioWriteBench.c b/src/base/io/ioWriteBench.c
index 4ca1ac0a..81d64582 100644
--- a/src/base/io/ioWriteBench.c
+++ b/src/base/io/ioWriteBench.c
@@ -57,7 +57,7 @@ int Io_WriteBench( Abc_Ntk_t * pNtk, const char * pFileName )
assert( Abc_NtkIsSopNetlist(pNtk) );
if ( !Io_WriteBenchCheckNames(pNtk) )
{
- fprintf( stdout, "Io_WriteBench(): Signal names in this benchmark contain parantheses making them impossible to reproduce in the BENCH format. Use \"short_names\".\n" );
+ fprintf( stdout, "Io_WriteBench(): Signal names in this benchmark contain parentheses making them impossible to reproduce in the BENCH format. Use \"short_names\".\n" );
return 0;
}
pFile = fopen( pFileName, "w" );
@@ -179,7 +179,7 @@ int Io_WriteBenchLut( Abc_Ntk_t * pNtk, char * pFileName )
assert( Abc_NtkIsAigNetlist(pNtk) );
if ( !Io_WriteBenchCheckNames(pNtk) )
{
- fprintf( stdout, "Io_WriteBenchLut(): Signal names in this benchmark contain parantheses making them impossible to reproduce in the BENCH format. Use \"short_names\".\n" );
+ fprintf( stdout, "Io_WriteBenchLut(): Signal names in this benchmark contain parentheses making them impossible to reproduce in the BENCH format. Use \"short_names\".\n" );
return 0;
}
pFile = fopen( pFileName, "w" );
diff --git a/src/base/io/ioWriteEqn.c b/src/base/io/ioWriteEqn.c
index d3784187..fb8ca43e 100644
--- a/src/base/io/ioWriteEqn.c
+++ b/src/base/io/ioWriteEqn.c
@@ -219,7 +219,7 @@ int Io_NtkWriteEqnCheck( Abc_Ntk_t * pNtk )
int i, k, Length;
int RetValue = 1;
- // make sure the network does not have proper names, such as "0" or "1" or containing parantheses
+ // make sure the network does not have proper names, such as "0" or "1" or containing parentheses
Abc_NtkForEachObj( pNtk, pObj, i )
{
pName = Nm_ManFindNameById(pNtk->pManName, i);
diff --git a/src/base/io/ioWriteList.c b/src/base/io/ioWriteList.c
index 22d0d1af..9e0ac88e 100644
--- a/src/base/io/ioWriteList.c
+++ b/src/base/io/ioWriteList.c
@@ -38,7 +38,7 @@ used it in order to reason on relatively small weighed direct graphs. I
simply list all vertices, one per line and for each vertex "V_source" I
list all vertices that are "sinks" with respect to it, i.e. such that
there is a distinct arc between "V_source" and each of them (in
-paranthesis I list the name of the edge and its weight (number of latency
+parenthesis I list the name of the edge and its weight (number of latency
on that path). For instance, if you look at the following graph, you have
that vertex "v_5" is connected to vertex "v_6" through a directed arc
called "v_5_to_v_6" whose latency is equal to 3, i.e. there are three
diff --git a/src/base/io/ioWriteSmv.c b/src/base/io/ioWriteSmv.c
index c767bcaa..5cb82da8 100644
--- a/src/base/io/ioWriteSmv.c
+++ b/src/base/io/ioWriteSmv.c
@@ -75,7 +75,7 @@ int Io_WriteSmv( Abc_Ntk_t * pNtk, char * pFileName )
assert( Abc_NtkIsSopNetlist(pNtk) );
if ( !Io_WriteSmvCheckNames(pNtk) )
{
- fprintf( stdout, "Io_WriteSmv(): Signal names in this benchmark contain parantheses making them impossible to reproduce in the SMV format. Use \"short_names\".\n" );
+ fprintf( stdout, "Io_WriteSmv(): Signal names in this benchmark contain parentheses making them impossible to reproduce in the SMV format. Use \"short_names\".\n" );
return 0;
}
pFile = fopen( pFileName, "w" );
diff --git a/src/base/io/ioReadDsd.c b/src/base/io/ioReadDsd.c
index 514c664a..09845699 100644
--- a/src/base/io/ioReadDsd.c
+++ b/src/base/io/ioReadDsd.c
@@ -90,17 +90,17 @@ int Io_ReadDsdStrSplit( char * pCur, char * pParts[], int * pTypeXor )
// skip hex truth table
while ( (*pCur >= '0' && *pCur <= '9') || (*pCur >= 'A' && *pCur <= 'F') )
pCur++;
- // process parantheses
+ // process parentheses
if ( *pCur != '(' )
{
- printf( "Cannot find the opening paranthesis.\n" );
+ printf( "Cannot find the opening parenthesis.\n" );
break;
}
// find the corresponding closing paranthesis
pCur = Io_ReadDsdFindEnd( pCur );
if ( pCur == NULL )
{
- printf( "Cannot find the closing paranthesis.\n" );
+ printf( "Cannot find the closing parenthesis.\n" );
break;
}
pCur++;
@@ -254,7 +254,7 @@ Abc_Ntk_t * Io_ReadDsd( char * pForm )
Abc_ObjAssignName( Abc_NtkCreatePi(pNtk), (char *)Vec_PtrEntry(vNames, i), NULL );
Abc_NodeFreeNames( vNames );
- // transform the formula by inserting parantheses
+ // transform the formula by inserting parentheses
// this transforms strings like PRIME(a,b,cd) into (PRIME((a),(b),(cd)))
pCur = pFormCopy = ABC_ALLOC( char, 3 * strlen(pForm) + 10 );
*pCur++ = '(';
@@ -90,17 +90,17 @@ int Io_ReadDsdStrSplit( char * pCur, char * pParts[], int * pTypeXor )
break;
}
- // find the corresponding closing paranthesis
+ // find the corresponding closing parenthesis
pCur = Io_ReadDsdFindEnd( pCur );
if ( pCur == NULL )